==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/Microsoft.JScript/Microsoft.JScript/BooleanConstructor.cs <==
//
// BooleanConstructor.cs:
//
// Author: Cesar Octavio Lopez Nataren
//
// (C) 2003, Cesar Octavio Lopez Nataren, <cesar@ciencias.unam.mx>
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace Microsoft.JScript {

	public class BooleanConstructor : ScriptFunction {

		internal static BooleanConstructor Ctr = new BooleanConstructor ();

		internal BooleanConstructor ()
		{
		}

		[JSFunctionAttribute(JSFunctionAttributeEnum.HasVarArgs)]	
		public new BooleanObject CreateInstance (params Object [] args)
		{
			if (args == null || args.Length == 0)
				return new BooleanObject ();
			else
				return new BooleanObject (args [0]);
		}

		public bool Invoke (Object arg)
		{
			throw new NotImplementedException ();
		}
	}
}

==> mono_1.2.4.orig.tar.gz: mono-1.2.4/mcs/class/Microsoft.JScript/Microsoft.JScript/BooleanConstructor.cs <==
//
// BooleanConstructor.cs:
//
// Author: Cesar Octavio Lopez Nataren
//
// (C) 2003, Cesar Octavio Lopez Nataren, <cesar@ciencias.unam.mx>
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace Microsoft.JScript {

	public class BooleanConstructor : ScriptFunction {

		internal static BooleanConstructor Ctr = new BooleanConstructor ();

		internal BooleanConstructor ()
		{
			_prototype = BooleanPrototype.Proto;
			_length = 1;
			name = "Boolean";
		}

		[JSFunctionAttribute(JSFunctionAttributeEnum.HasVarArgs)]	
		public new BooleanObject CreateInstance (params Object [] args)
		{
			if (args == null || args.Length == 0)
				return new BooleanObject ();
			else
				return new BooleanObject (args [0]);
		}

		public bool Invoke (Object arg)
		{
			return Convert.ToBoolean (arg);
		}
	}
}
